@@ -1,21 +1,25 @@
-/* Evolution calendar - Configuration values for the alarm notification daemon
- *
- * Copyright (C) 2001 Ximian, Inc.
- *
- * Authors: Federico Mena-Quintero <federico@ximian.com>
+/*
+ * Evolution calendar - Configuration values for the alarm notification daemon
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Federico Mena-Quintero <federico@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIOH
@@ -255,7 +259,7 @@ void
 config_data_set_last_notification_time (time_t t)
 {
 	GConfClient *client;
-	time_t current_t;
+	time_t current_t, now = time (NULL);
 
 	g_return_if_fail (t != -1);
 
@@ -265,7 +269,7 @@ config_data_set_last_notification_time (time_t t)
 	/* we only store the new notification time if it is bigger
 	   than the already stored one */
 	current_t = gconf_client_get_int (client, KEY_LAST_NOTIFICATION_TIME, NULL);
-	if (t > current_t)
+	if (t > current_t || current_t > now)
 		gconf_client_set_int (client, KEY_LAST_NOTIFICATION_TIME, t, NULL);
 }
 
@@ -286,8 +290,14 @@ config_data_get_last_notification_time (void)
 		return -1;
 
 	value = gconf_client_get_without_default (client, KEY_LAST_NOTIFICATION_TIME, NULL);
-	if (value)
-		return (time_t) gconf_value_get_int (value);
+	if (value) {
+		time_t val = (time_t) gconf_value_get_int (value), now = time (NULL);
+
+		if (val > now)
+			val = now;
+
+		return val;
+	}
 
 	return time (NULL);
 }
