@@ -1,20 +1,18 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #include "e-composer-actions.h"
@@ -86,7 +84,7 @@ action_attach_cb (GtkAction *action,
 		if (!g_ascii_strcasecmp (url->protocol, "file"))
 			e_attachment_bar_attach (bar, url->path, disposition);
 		else
-			e_attachment_bar_attach (bar, iter->data, disposition);
+			e_attachment_bar_attach_remote_file (bar, iter->data, disposition);
 
 		camel_url_free (url);
 	}
@@ -127,9 +125,8 @@ action_close_cb (GtkAction *action,
 	editor = GTKHTML_EDITOR (composer);
 	widget = GTK_WIDGET (composer);
 
-	if (!gtkhtml_editor_get_changed (editor) &&
-		e_composer_autosave_get_saved (composer)) {
-
+	if (!gtkhtml_editor_get_changed (editor) ||
+	    e_msg_composer_is_exiting (composer)) {
 		gtk_widget_destroy (widget);
 		return;
 	}
@@ -247,7 +244,7 @@ action_save_cb (GtkAction *action,
 			e_error_run (
 				GTK_WINDOW (composer),
 				E_ERROR_NO_SAVE_FILE, filename,
-				g_strerror (errno_saved));
+				g_strerror (errno_saved), NULL);
 			return;
 		}
 	} else
@@ -257,7 +254,7 @@ action_save_cb (GtkAction *action,
 		e_error_run (
 			GTK_WINDOW (composer),
 			E_ERROR_NO_SAVE_FILE,
-			filename, error->message);
+			filename, error->message, NULL);
 		g_error_free (error);
 		return;
 	}
@@ -511,7 +508,7 @@ static GtkActionEntry entries[] = {
 
 	{ "save-draft",
 	  GTK_STOCK_SAVE,
-	  N_("Save _Draft"),
+	  N_("Save as _Draft"),
 	  "<Shift><Control>s",
 	  N_("Save as draft"),
 	  G_CALLBACK (action_save_draft_cb) },
@@ -696,10 +693,12 @@ e_composer_actions_init (EMsgComposer *composer)
 	/* Fine Tuning */
 
 	g_object_set (
-		G_OBJECT (ACTION (ATTACH)),
-		"short-label", _("Attach"), NULL);
+		ACTION (ATTACH), "short-label", _("Attach"), NULL);
 
-#if defined (HAVE_NSS) && defined (SMIME_SUPPORTED)
+	g_object_set (
+		ACTION (SAVE_DRAFT), "short-label", _("Save Draft"), NULL);
+
+#if defined (HAVE_NSS)
 	visible = TRUE;
 #else
 	visible = FALSE;
